@@ -1,6 +1,8 @@
-/*  $Id: clipman-dialogs.c 4018 2008-03-04 15:15:08Z mmassonnet $
+/*  $Id: clipman-dialogs.c 6461 2009-01-15 07:55:19Z mmassonnet $
  *
  *  Copyright (c) 2006-2007 Nick Schermer <nick@xfce.org>
+ *  Copyright (c) 2008      David Collins <david.8.collins@gmail.com>
+ *  Copyright (c) 2009      Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,13 +39,9 @@ typedef struct
     ClipmanPlugin *clipman;
 
     GtkWidget     *ExitSave;
-    GtkWidget     *IgnoreSelection;
-    GtkWidget     *PreventEmpty;
-
-    GtkWidget     *Behaviour;
+    GtkWidget     *AddSelection;
 
     GtkWidget     *ItemNumbers;
-    GtkWidget     *SeparateMenu;
 
     GtkWidget     *HistorySize;
     GtkWidget     *ItemChars;
@@ -63,7 +61,7 @@ clipman_configure_response (GtkWidget      *dialog,
         result = g_spawn_command_line_async ("exo-open --launch WebBrowser " PLUGIN_WEBSITE, NULL);
 
         if (G_UNLIKELY (result == FALSE))
-            g_warning (_("Unable to open the following url: %s"), PLUGIN_WEBSITE);
+            xfce_warn (_("Unable to open the following url: %s"), PLUGIN_WEBSITE);
 
         return;
 	}
@@ -72,23 +70,16 @@ clipman_configure_response (GtkWidget      *dialog,
 
     g_object_set_data (G_OBJECT (options->clipman->plugin), "dialog", NULL);
 
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (options->Behaviour)))
-        options->clipman->Behaviour = NORMAL;
-    else
-        options->clipman->Behaviour = STRICTLY;
-
     if (options->clipman->HistoryItems != gtk_range_get_value (GTK_RANGE (options->HistorySize)))
     {
         options->clipman->HistoryItems   = gtk_range_get_value (GTK_RANGE (options->HistorySize));
-        clipman_check_array_len (options->clipman);
+        clipman_array_remove_oldest (options->clipman);
     }
 
     options->clipman->MenuCharacters = gtk_range_get_value (GTK_RANGE (options->ItemChars));
 
     clipman_save (options->clipman->plugin, options->clipman);
 
-    clipman_remove_selection_clips (options->clipman);
-
     xfce_panel_plugin_unblock_menu (options->clipman->plugin);
 
     gtk_widget_destroy (dialog);
@@ -122,27 +113,13 @@ toggle_button (GtkWidget      *button,
         options->clipman->ExitSave =
            gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 
-    else if (button == options->IgnoreSelection)
-    {
-        options->clipman->IgnoreSelect =
-           gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
-
-        if (options->clipman->IgnoreSelect)
-            gtk_widget_set_sensitive (options->SeparateMenu, FALSE);
-        else
-            gtk_widget_set_sensitive (options->SeparateMenu, TRUE);
-    }
-    else if (button == options->PreventEmpty)
-        options->clipman->PreventEmpty =
+    else if (button == options->AddSelection)
+        options->clipman->AddSelect =
            gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 
     else if (button == options->ItemNumbers)
         options->clipman->ItemNumbers =
            gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
-
-    else if (button == options->SeparateMenu)
-        options->clipman->SeparateMenu =
-           gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 }
 
 void
@@ -152,7 +129,6 @@ clipman_configure (XfcePanelPlugin *plugin,
     GtkWidget      *dialog, *dialog_vbox, *frame, *button, *label;
     GtkWidget      *vbox, *hbox, *notebook_vbox, *notebook;
     ClipmanOptions *options;
-    GSList         *group;
 
     options = panel_slice_new0 (ClipmanOptions);
     options->clipman = clipman;
@@ -167,13 +143,14 @@ clipman_configure (XfcePanelPlugin *plugin,
                                                   NULL);
 
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-    gtk_window_set_icon_name (GTK_WINDOW (dialog), "xfce4-settings");
+    gtk_window_set_icon_name (GTK_WINDOW (dialog), "gtk-paste");
 
     g_object_set_data (G_OBJECT (clipman->plugin), "dialog", dialog);
 
     dialog_vbox = GTK_DIALOG (dialog)->vbox;
 
     notebook = gtk_notebook_new ();
+    gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
     gtk_box_pack_start (GTK_BOX (dialog_vbox), notebook, FALSE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (notebook), BORDER-3);
 
@@ -198,82 +175,13 @@ clipman_configure (XfcePanelPlugin *plugin,
     g_signal_connect (G_OBJECT (button), "toggled",
             G_CALLBACK (toggle_button), options);
 
-    button = options->IgnoreSelection = gtk_check_button_new_with_mnemonic (_("_Ignore selections"));
+    button = options->AddSelection = gtk_check_button_new_with_mnemonic (_("A_dd selections to the history"));
     gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), clipman->IgnoreSelect);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), clipman->AddSelect);
 
     g_signal_connect (G_OBJECT (button), "toggled",
             G_CALLBACK (toggle_button), options);
 
-    button = options->PreventEmpty = gtk_check_button_new_with_mnemonic (_("Pre_vent empty clipboard"));
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), clipman->PreventEmpty);
-
-    g_signal_connect (G_OBJECT (button), "toggled",
-            G_CALLBACK (toggle_button), options);
-
-
-    label = gtk_label_new (_("<b>General</b>"));
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_padding (GTK_MISC (label), 2, 0);
-
-    /**
-     * separate clipboards frame
-     **/
-    frame = gtk_frame_new (NULL);
-    gtk_box_pack_start (GTK_BOX (notebook_vbox), frame, FALSE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (frame), BORDER-3);
-
-    vbox = gtk_vbox_new (FALSE, 2);
-    gtk_container_add (GTK_CONTAINER (frame), vbox);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
-
-    group = NULL;
-
-    button = options->Behaviour = gtk_radio_button_new_with_mnemonic (group, _("Normal clipboard _management"));
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (button), group);
-    group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (button));
-
-    if(clipman->Behaviour == NORMAL)
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-
-    button = gtk_radio_button_new_with_mnemonic (group, _("Strictly separate _both clipboards"));
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (button), group);
-    group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (button));
-
-    if(clipman->Behaviour == STRICTLY)
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-
-    label = gtk_label_new (_("<b>Clipboard Behaviour</b>"));
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_padding (GTK_MISC (label), 2, 0);
-
-    /**
-     * Notebook label
-     **/
-    label = gtk_label_new (_("General"));
-    gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), label);
-
-    notebook_vbox = gtk_vbox_new (FALSE, 2);
-    gtk_container_add (GTK_CONTAINER (notebook), notebook_vbox);
-
-    /**
-     * Menu appearance frame
-     **/
-    frame = gtk_frame_new (NULL);
-    gtk_box_pack_start (GTK_BOX (notebook_vbox), frame, FALSE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (frame), BORDER-3);
-
-    vbox = gtk_vbox_new (FALSE, 2);
-    gtk_container_add (GTK_CONTAINER (frame), vbox);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
-
     button = options->ItemNumbers = gtk_check_button_new_with_mnemonic (_("_Show item numbers"));
     gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), clipman->ItemNumbers);
@@ -281,24 +189,11 @@ clipman_configure (XfcePanelPlugin *plugin,
     g_signal_connect (G_OBJECT (button), "toggled",
             G_CALLBACK (toggle_button), options);
 
-    button = options->SeparateMenu = gtk_check_button_new_with_mnemonic (_("Se_parate clipboards"));
-    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), clipman->SeparateMenu);
-
-    g_signal_connect (G_OBJECT (button), "toggled",
-            G_CALLBACK (toggle_button), options);
-
-    label = gtk_label_new (_("<b>Menu Appearance</b>"));
+    label = gtk_label_new (_("<b>General</b>"));
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_padding (GTK_MISC (label), 2, 0);
 
-    /**
-     * Call some functions
-     **/
-
-   toggle_button (options->IgnoreSelection, options);
-
     /**
      * Numbers frame
      **/
@@ -361,8 +256,17 @@ clipman_configure (XfcePanelPlugin *plugin,
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_padding (GTK_MISC (label), 4, 0);
 
-    label = gtk_label_new (_("Appearance"));
-    gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 1), label);
+    /**
+     * Notebook label
+     **/
+    label = gtk_label_new (_("General"));
+    gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), label);
+
+    /**
+     * Call some functions
+     **/
+
+   toggle_button (options->AddSelection, options);
 
     g_signal_connect(dialog, "response",
         G_CALLBACK(clipman_configure_response), options);
