@@ -1,6 +1,8 @@
-/*  $Id: clipman.h 4018 2008-03-04 15:15:08Z mmassonnet $
+/*  $Id: clipman.h 6461 2009-01-15 07:55:19Z mmassonnet $
  *
  *  Copyright (c) 2006-2007 Nick Schermer <nick@xfce.org>
+ *  Copyright (c) 2008-2009 David Collins <david.8.collins@gmail.com>
+ *  Copyright (c) 2009      Mike Massonnet <mmassonnet@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,16 +39,14 @@ G_BEGIN_DECLS
 
 /* Default options */
 #define DEFEXITSAVE     FALSE
-#define DEFIGNORESELECT TRUE
-#define DEFPREVENTEMPTY TRUE
-#define DEFBEHAVIOUR    1
-
+#define DEFADDSELECT    FALSE
 #define DEFITEMNUMBERS  FALSE
-#define DEFSEPMENU      FALSE
 
 /* Milisecond to check the clipboards(s) */
 #define TIMER_INTERVAL  500
 
+#define CLIPIMAGETITLE   "**IMAGE**"
+
 typedef enum
 {
     PRIMARY = 0,
@@ -56,10 +56,18 @@ ClipboardType;
 
 typedef enum
 {
-    NORMAL = 0,
-    STRICTLY
+    RAWTEXT,
+    IMAGE
 }
-ClipboardBehaviour;
+ClipDataType;
+
+typedef enum
+{
+    PLAIN,
+    BOLD,
+    ITALICS
+}
+ClipMenuFormat;
 
 typedef struct
 {
@@ -69,19 +77,18 @@ typedef struct
     GtkWidget    *button;
     GtkTooltips  *tooltip;
 
-    GPtrArray    *clips;
-
     gint          TimeoutId;
     gboolean      killTimeout;
 
     gboolean      ExitSave;
-    gboolean      IgnoreSelect;
-    gboolean      PreventEmpty;
+    gboolean      AddSelect;
 
-    ClipboardBehaviour Behaviour;
+    GPtrArray    *clips;
+    gint          DefaultIndex;
+    gint          PrimaryIndex;
+    GSList       *actions;
 
     gboolean      ItemNumbers;
-    gboolean      SeparateMenu;
 
     guint         HistoryItems;
     guint         MenuCharacters;
@@ -90,10 +97,10 @@ ClipmanPlugin;
 
 typedef struct
 {
-    gchar        *text;
-    gchar        *title;        /* I've added the title to save
-                                 * some time when opening the menu */
-    ClipboardType fromtype;
+    void         *data;
+    gchar        *title;
+    GdkPixbuf    *preview;
+    ClipDataType  datatype;
 }
 ClipmanClip;
 
@@ -101,18 +108,18 @@ typedef struct
 {
     ClipmanPlugin  *clipman;
     ClipmanClip    *clip;
+    gint            index;
 }
 ClipmanAction;
 
 void
-clipman_check_array_len        (ClipmanPlugin *clipman);
+clipman_array_remove_oldest   (ClipmanPlugin *clipman);
 
 void
-clipman_save                   (XfcePanelPlugin *plugin, ClipmanPlugin *clipman);
+clipman_save                  (XfcePanelPlugin *plugin, ClipmanPlugin *clipman);
 
-void
-clipman_remove_selection_clips (ClipmanPlugin *clipman);
 
 G_END_DECLS
 
 #endif /* CLIPMAN_H */
+
